@@ -2,8 +2,8 @@ package Dist::Zilla::Plugin::Run;
 BEGIN {
   $Dist::Zilla::Plugin::Run::AUTHORITY = 'cpan:GETTY';
 }
-BEGIN {
-  $Dist::Zilla::Plugin::Run::VERSION = '0.006';
+{
+  $Dist::Zilla::Plugin::Run::VERSION = '0.007';
 }
 # ABSTRACT: Running external commands on specific hooks of Dist::Zilla
 use strict;
@@ -21,24 +21,55 @@ Dist::Zilla::Plugin::Run - Running external commands on specific hooks of Dist::
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
   [Run::BeforeRelease]
   run = script/myapp_before1.pl %s
-  run = script/myapp_before2.pl %s
+  run = script/myapp_before2.pl %n %v
 
   [Run::Release]
   run = script/myapp_deploy1.pl %s
-  run = script/myapp_deploy2.pl %s
+  run = deployer.pl --dir %d --tgz %a --name %n --version %v
 
   [Run::AfterRelease]
-  run = script/myapp_after.pl %s
+  run = script/myapp_after.pl %s %v
 
 =head1 DESCRIPTION
 
-Please be aware that so far just commands are possible which are inside your distribution (its a TODO to fix this).
+Run arbitrary commands at various L<Dist::Zilla> phases.
+
+=head1 CONVERSIONS
+
+The following conversions/format specifiers are defined
+for passing as arguments to the specified commands
+(though not all values are available at all phases).
+
+=over 4
+
+=item *
+
+C<%a> the archive of the release (available to all C<*Release> phases)
+
+=item *
+
+C<%d> the directory in which the dist was built (not in C<BeforeBuild>)
+
+=item *
+
+C<%n> the dist name
+
+=item *
+
+C<%v> the dist version
+
+=back
+
+Additionally C<%s> is retained for backward compatibility.
+Each occurrence is replaced by a different value
+(like the regular C<sprintf> function).
+Individual plugins define their own values for the positional replacement of C<%s>.
 
 =head1 AUTHOR
 
