@@ -2,8 +2,8 @@ package Dist::Zilla::Plugin::Run::AfterBuild;
 BEGIN {
   $Dist::Zilla::Plugin::Run::AfterBuild::AUTHORITY = 'cpan:GETTY';
 }
-BEGIN {
-  $Dist::Zilla::Plugin::Run::AfterBuild::VERSION = '0.006';
+{
+  $Dist::Zilla::Plugin::Run::AfterBuild::VERSION = '0.007';
 }
 # ABSTRACT: execute a command of the distribution after build
 use Moose;
@@ -16,8 +16,10 @@ use namespace::autoclean;
 
 sub after_build {
     my ($self, $param) = @_;
-    
-	$self->call_script($param->{ build_root }, $self->zilla->version);
+  $self->call_script({
+    dir =>  $param->{ build_root },
+    pos => [$param->{ build_root }, $self->zilla->version]
+  });
 }
 
 
@@ -32,7 +34,7 @@ Dist::Zilla::Plugin::Run::AfterBuild - execute a command of the distribution aft
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -42,12 +44,26 @@ version 0.006
 
 =head1 DESCRIPTION
 
-This plugin executes after build a command, if its given on config. The 1st %s get replaced by the directory, containing the distribution just built.
-The 2nd - by the version of the distribution.
+This plugin executes the specified command after building the dist.
 
-=head2 notexist_fatal
+=head1 POSITIONAL PARAMETERS
 
-If this value is set to false, the plugin will ignore a not existing script. Default is true.
+See L<Dist::Zilla::Plugin::Run/CONVERSIONS>
+for the list of common formatting variables available to all plugins.
+
+For backward compatibility:
+
+=over 4
+
+=item *
+
+The 1st C<%s> will be replaced by the directory in which the dist was built.
+
+=item *
+
+The 2nd C<%s> will be replaced by the dist version.
+
+=back
 
 =head1 AUTHOR
 
