@@ -2,8 +2,8 @@ package Dist::Zilla::Plugin::Run::AfterRelease;
 BEGIN {
   $Dist::Zilla::Plugin::Run::AfterRelease::AUTHORITY = 'cpan:GETTY';
 }
-BEGIN {
-  $Dist::Zilla::Plugin::Run::AfterRelease::VERSION = '0.006';
+{
+  $Dist::Zilla::Plugin::Run::AfterRelease::VERSION = '0.007';
 }
 # ABSTRACT: execute a command of the distribution after release
 use Moose;
@@ -15,9 +15,11 @@ with qw(
 use namespace::autoclean;
 
 sub after_release {
-    my $self = shift;
-    
-	$self->call_script(@_, $self->zilla->version);
+  my ( $self, $archive ) = @_;
+  $self->call_script({
+    archive =>  $archive,
+    pos     => [$archive, $self->zilla->version]
+  });
 }
 
 
@@ -32,7 +34,7 @@ Dist::Zilla::Plugin::Run::AfterRelease - execute a command of the distribution a
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -46,12 +48,26 @@ or
 
 =head1 DESCRIPTION
 
-This plugin executes after release a command, if its given on config. The 1st %s get replaced by the archive of the release.
-The 2nd - by the version of the distribution.
+This plugin executes the specified command after releasing.
 
-=head2 notexist_fatal
+=head1 POSITIONAL PARAMETERS
 
-If this value is set to false, the plugin will ignore a not existing script. Default is true.
+See L<Dist::Zilla::Plugin::Run/CONVERSIONS>
+for the list of common formatting variables available to all plugins.
+
+For backward compatibility:
+
+=over 4
+
+=item *
+
+The 1st C<%s> will be replaced by the archive of the release.
+
+=item *
+
+The 2nd C<%s> will be replaced by the dist version.
+
+=back
 
 =head1 AUTHOR
 
