@@ -2,8 +2,8 @@ package Dist::Zilla::Plugin::Run::Release;
 BEGIN {
   $Dist::Zilla::Plugin::Run::Release::AUTHORITY = 'cpan:GETTY';
 }
-BEGIN {
-  $Dist::Zilla::Plugin::Run::Release::VERSION = '0.006';
+{
+  $Dist::Zilla::Plugin::Run::Release::VERSION = '0.007';
 }
 # ABSTRACT: execute a command of the distribution on release
 use Moose;
@@ -15,7 +15,11 @@ with qw(
 use namespace::autoclean;
 
 sub release {
-	shift->call_script(@_);
+  my ( $self, $archive ) = @_;
+  $self->call_script({
+    archive =>  $archive,
+    pos     => [$archive]
+  });
 }
 
 
@@ -30,7 +34,7 @@ Dist::Zilla::Plugin::Run::Release - execute a command of the distribution on rel
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -44,11 +48,24 @@ or
 
 =head1 DESCRIPTION
 
-This plugin executes on release a command, if its given on config. The %s get replaced by the archive of the release.
+This plugin executes the specified command for the release process.
 
-=head2 notexist_fatal
+This way you can specify a custom release command without needing any other C<Releaser> plugin.
 
-If this value is set to false, the plugin will ignore a not existing script. Default is true.
+=head1 POSITIONAL PARAMETERS
+
+See L<Dist::Zilla::Plugin::Run/CONVERSIONS>
+for the list of common formatting variables available to all plugins.
+
+For backward compatibility:
+
+=over 4
+
+=item *
+
+The 1st C<%s> will be replaced by the archive of the release.
+
+=back
 
 =head1 AUTHOR
 
