@@ -2,11 +2,12 @@ package Dist::Zilla::Plugin::Run::Role::Runner;
 BEGIN {
   $Dist::Zilla::Plugin::Run::Role::Runner::AUTHORITY = 'cpan:GETTY';
 }
-BEGIN {
-  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.006';
+{
+  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.007';
 }
 # ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
 use Moose::Role;
+use String::Formatter 0.102082 ();
 use namespace::autoclean;
 
 has run => (
@@ -15,27 +16,33 @@ has run => (
 	default => sub { [] },
 );
 
-has notexist_fatal => (
-	is => 'ro',
-	isa => 'Bool',
-	default => sub { 1 },
-);
+around BUILDARGS => sub {
+    my ( $orig, $class, @args ) = @_;
+    my $built = $class->$orig(@args);
 
+    foreach my $dep (qw( notexist_fatal )) {
+        if ( exists $built->{$dep} ) {
+            warn(" !\n ! $class attribute '$dep' is deprecated and has no effect.\n !\n");
+            delete $built->{$dep};
+        }
+    }
+    return $built;
+};
 
 sub call_script {
-	my ( $self, @params ) = @_;
+	my ( $self, $params ) = @_;
 
     foreach my $run_cmd (@{$self->run}) {
 
         if ($run_cmd) {
-            
-		my $command = sprintf($run_cmd,@params);
+            my $command = $self->build_formatter($params)->format($run_cmd);
 		$self->log("Executing: ".$command);
 		my $output = `$command`;
+		my $status = $?;
 		$self->log($output);
-		$self->log_fatal("Errorlevel ".$?." on command execute") if $?;     
+		$self->log_fatal("Errorlevel ".$status." on command execute") if $status;
 		$self->log("command executed successful");
-            
+
         }
     } 
 }
@@ -50,6 +57,25 @@ around mvp_multivalue_args => sub {
     @res; 
 };
 
+sub build_formatter {
+    my ( $self, $params ) = @_;
+
+    # stringify build directory
+    my $dir = $params->{dir} || $self->zilla->built_in;
+    $dir = $dir ? "$dir" : '';
+
+    return String::Formatter->new({
+        codes => {
+            # not always available
+            a => $params->{archive} || '',
+            d => $dir,
+            n => $self->zilla->name,
+            v => $self->zilla->version,
+            # positional replace (backward compatible)
+            s => sub { shift(@{ $params->{pos} }) || '' },
+        },
+    });
+}
 
 
 1;
@@ -63,7 +89,7 @@ Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::P
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
